@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcart_dialog.cpp,v 1.40.2.2 2009/11/25 17:19:24 cvs Exp $
+//      $Id: rdcart_dialog.cpp,v 1.48.4.8 2014/02/11 23:46:25 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,18 +20,30 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <stdlib.h>
+#include <stdio.h>
+
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qsqlquery.h>
 #include <qdatetime.h>
 #include <qapplication.h>
 #include <qeventloop.h>
+#include <qfiledialog.h>
+#include <qmessagebox.h>
 
 #include <rdconf.h>
 #include <rdcart_dialog.h>
 #include <rdcart_search_text.h>
 #include <rdtextvalidator.h>
+#include <rdprofile.h>
 #include <rddb.h>
+#include <rdgroup.h>
+#ifndef WIN32
+#include <rdaudioimport.h>
+#endif  // WIN32
+#include <rdsettings.h>
+#include <rdwavefile.h>
 
 //
 // Icons
@@ -39,14 +51,10 @@
 #include "../icons/play.xpm"
 #include "../icons/rml5.xpm"
 
-
-RDCartDialog::RDCartDialog(QString *filter,QString *group,
-			   int audition_card,int audition_port,
-			   unsigned start_cart,unsigned end_cart,RDCae *cae,
-			   RDRipc *ripc,RDStation *station,
-			   const QString &edit_cmd,
-			   QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
+			   RDCae *cae,RDRipc *ripc,RDStation *station,
+			   RDSystem *system,RDConfig *config,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   //
   // Fix the Window Size
@@ -54,10 +62,14 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,
   setMinimumWidth(sizeHint().width());
   setMinimumHeight(sizeHint().height());
 
+  cart_station=station;
+  cart_system=system;
+  cart_config=config;
   cart_cartnum=NULL;
   cart_type=RDCart::All;
   cart_group=group;
-  cart_edit_cmd=edit_cmd;
+  cart_schedcode=schedcode;
+  cart_temp_allowed=NULL;
 #ifdef WIN32
   cart_filter_mode=RDStation::FilterSynchronous;
 #else
@@ -72,6 +84,8 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,
     cart_filter=filter;
     local_filter=false;
   }
+  cart_import_path=RDGetHomeDir();
+  cart_import_file_filter=RD_AUDIO_FILE_FILTER;
 
   setCaption(tr("Select Cart"));
 
@@ -108,11 +122,13 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,
   cart_progress_dialog->setLabel(label);
   cart_progress_dialog->setCancelButton(NULL);
   cart_progress_dialog->setMinimumDuration(2000);
+  
+  cart_busy_dialog=new RDBusyDialog(this);
 
   //
   // Filter Selector
   //
-  cart_filter_edit=new QLineEdit(this,"cart_filter_edit");
+  cart_filter_edit=new QLineEdit(this);
   cart_filter_edit->setValidator(validator);
   cart_filter_label=new QLabel(cart_filter_edit,tr("Cart Filter:"),
 		   this,"cart_filter_label");
@@ -124,7 +140,7 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,
   //
   // Filter Search Button
   //
-  cart_search_button=new QPushButton(this,"cart_search_button");
+  cart_search_button=new QPushButton(this);
   cart_search_button->setText(tr("&Search"));
   cart_search_button->setFont(button_font);
   connect(cart_search_button,SIGNAL(clicked()),this,SLOT(filterSearchedData()));
@@ -132,26 +148,50 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,
   //
   // Filter Clear Button
   //
-  cart_clear_button=new QPushButton(this,"cart_clear_button");
+  cart_clear_button=new QPushButton(this);
   cart_clear_button->setText(tr("C&lear"));
   cart_clear_button->setFont(button_font);
   connect(cart_clear_button,SIGNAL(clicked()),this,SLOT(filterClearedData()));
 
   //
-  // Group Selector
+  // Group Code Selector
   //
-  cart_group_box=new RDComboBox(this,"cart_group_box");
-  cart_group_label=new QLabel(cart_group_box,tr("Group:"),
-			   this,"cart_group_label");
+  cart_group_box=new RDComboBox(this);
+  cart_group_label=new QLabel(cart_group_box,tr("Group:"),this);
   cart_group_label->setAlignment(AlignRight|AlignVCenter);
   cart_group_label->setFont(button_font);
   connect(cart_group_box,SIGNAL(activated(const QString &)),
 	  this,SLOT(groupActivatedData(const QString &)));
 
+  //
+  // Scheduler Code Selector
+  //
+  cart_schedcode_box=new RDComboBox(this);
+  cart_schedcode_label=
+    new QLabel(cart_schedcode_box,tr("Scheduler Code:"),this);
+  cart_schedcode_label->setAlignment(AlignRight|AlignVCenter);
+  cart_schedcode_label->setFont(button_font);
+  connect(cart_schedcode_box,SIGNAL(activated(const QString &)),
+	  this,SLOT(schedcodeActivatedData(const QString &)));
+
+  //
+  // Search Limit Checkbox
+  //
+  cart_limit_box=new QCheckBox(this);
+  cart_limit_box->setChecked(true);
+  cart_limit_label=
+    new QLabel(cart_limit_box,tr("Show Only First")+
+	       QString().sprintf(" %d ",
+		      RD_LIMITED_CART_SEARCH_QUANTITY)+tr("Matches"),this);
+  cart_limit_label->setAlignment(AlignLeft|AlignVCenter);
+  cart_limit_label->setFont(button_font);
+  connect(cart_limit_box,SIGNAL(stateChanged(int)),
+	  this,SLOT(limitChangedData(int)));
+
   //
   // Cart List
   //
-  cart_cart_list=new RDListView(this,"cart_cart_list");
+  cart_cart_list=new RDListView(this);
   cart_cart_list->setSelectionMode(QListView::Single);
   cart_cart_list->setAllColumnsShowFocus(true);
   cart_cart_list->setItemMargin(5);
@@ -161,42 +201,60 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,
 	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
 	  this,
 	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
-  cart_cart_label=new QLabel(cart_cart_list,"Carts",this,"cart_cart_label");
+  cart_cart_label=new QLabel(cart_cart_list,"Carts",this);
   cart_cart_label->setFont(button_font);
   cart_cart_list->addColumn("");
   cart_cart_list->setColumnAlignment(0,Qt::AlignHCenter);
+
   cart_cart_list->addColumn(tr("NUMBER"));
   cart_cart_list->setColumnAlignment(1,Qt::AlignHCenter);
+
   cart_cart_list->addColumn(tr("LENGTH"));
   cart_cart_list->setColumnAlignment(2,Qt::AlignRight);
+  cart_cart_list->setColumnSortType(2,RDListView::TimeSort);
+
   cart_cart_list->addColumn(tr("TITLE"),200);
   cart_cart_list->setColumnAlignment(3,Qt::AlignLeft);
   cart_cart_list->setColumnWidthMode(3,QListView::Manual);
+
   cart_cart_list->addColumn(tr("ARTIST"));
   cart_cart_list->setColumnAlignment(4,Qt::AlignLeft);
+
   cart_cart_list->addColumn(tr("GROUP"));
   cart_cart_list->setColumnAlignment(5,Qt::AlignLeft);
-  cart_cart_list->addColumn(tr("CLIENT"));
+
+  cart_cart_list->addColumn(tr("COMPOSER"));
   cart_cart_list->setColumnAlignment(6,Qt::AlignLeft);
-  cart_cart_list->addColumn(tr("AGENCY"));
+
+  cart_cart_list->addColumn(tr("CONDUCTOR"));
   cart_cart_list->setColumnAlignment(7,Qt::AlignLeft);
-  cart_cart_list->addColumn(tr("USER DEF"));
+
+  cart_cart_list->addColumn(tr("CLIENT"));
   cart_cart_list->setColumnAlignment(8,Qt::AlignLeft);
-  cart_cart_list->addColumn(tr("START"));
+
+  cart_cart_list->addColumn(tr("AGENCY"));
   cart_cart_list->setColumnAlignment(9,Qt::AlignLeft);
-  cart_cart_list->addColumn(tr("END"));
+
+  cart_cart_list->addColumn(tr("USER DEF"));
   cart_cart_list->setColumnAlignment(10,Qt::AlignLeft);
 
+  cart_cart_list->addColumn(tr("START"));
+  cart_cart_list->setColumnAlignment(11,Qt::AlignLeft);
+
+  cart_cart_list->addColumn(tr("END"));
+  cart_cart_list->setColumnAlignment(12,Qt::AlignLeft);
+
   //
   // Audition Player
   //
 #ifndef WIN32
-  if((cae==NULL)||(audition_card<0)||(audition_port<0)) {
+  if((cae==NULL)||(station->cueCard()<0)||(station->cuePort()<0)) {
     cart_player=NULL;
   }
   else {
-    cart_player=new RDSimplePlayer(cae,ripc,audition_card,audition_port,
-				   start_cart,end_cart,this,"cart_player");
+    cart_player=
+      new RDSimplePlayer(cae,ripc,station->cueCard(),station->cuePort(),
+			 station->cueStartCart(),station->cueStopCart(),this);
     cart_player->playButton()->setDisabled(true);
     cart_player->stopButton()->setDisabled(true);
     cart_player->stopButton()->setOnColor(red);
@@ -206,25 +264,37 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,
   //
   // Send to Editor Button
   //
-  cart_editor_button=
-    new QPushButton(tr("Send to\n&Editor"),this,"cart_editor_button");
+  cart_editor_button=new QPushButton(tr("Send to\n&Editor"),this);
   cart_editor_button->setFont(button_font);
   connect(cart_editor_button,SIGNAL(clicked()),this,SLOT(editorData()));
-  if(edit_cmd.isEmpty()) {
+  if(station->editorPath().isEmpty()) {
     cart_editor_button->hide();
   }
 
+  //
+  // Load From File Button
+  //
+  cart_file_button=new QPushButton(tr("Load From\n&File"),this);
+  cart_file_button->setFont(button_font);
+  connect(cart_file_button,SIGNAL(clicked()),this,SLOT(loadFileData()));
+  if(station->editorPath().isEmpty()) {
+    cart_file_button->hide();
+  }
+#ifdef WIN32
+  cart_file_button->hide();
+#endif  // WIN32
+
   //
   // OK Button
   //
-  cart_ok_button=new QPushButton(tr("&OK"),this,"cart_ok_button");
+  cart_ok_button=new QPushButton(tr("&OK"),this);
   cart_ok_button->setFont(button_font);
   connect(cart_ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
   // Cancel Button
   //
-  cart_cancel_button=new QPushButton(tr("&Cancel"),this,"cart_cancel_button");
+  cart_cancel_button=new QPushButton(tr("&Cancel"),this);
   cart_cancel_button->setFont(button_font);
   connect(cart_cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 }
@@ -247,26 +317,36 @@ RDCartDialog::~RDCartDialog()
 
 QSize RDCartDialog::sizeHint() const
 {
-  return QSize(550,370);
+  return QSize(640,400);
 }
 
-
 int RDCartDialog::exec(int *cartnum,RDCart::Type type,QString *svcname,
-		       int svc_quan)
+		       int svc_quan,const QString &username,
+		       const QString &passwd,bool *temp_allowed)
 {
+  LoadState();
   cart_cartnum=cartnum;
   cart_type=type;
   cart_service=svcname;
   cart_service_quan=svc_quan;
+  cart_user_name=username;
+  cart_user_password=passwd;
+  cart_temp_allowed=temp_allowed;
   switch(cart_type) {
     case RDCart::All:
     case RDCart::Audio:
-      if(cart_edit_cmd.isEmpty()) {
+      if(cart_station->editorPath().isEmpty()) {
 	cart_editor_button->hide();
       }
       else {
 	cart_editor_button->show();
       }
+      if(temp_allowed==NULL) {
+	cart_file_button->hide();
+      }
+      else {
+	cart_file_button->show();
+      }
 #ifndef WIN32
       if(cart_player!=NULL) {
 	cart_player->playButton()->show();
@@ -359,6 +439,27 @@ void RDCartDialog::groupActivatedData(const QString &group)
   if(cart_group!=NULL) {
     *cart_group=group;
   }
+  if(cart_group!=NULL) {
+    *cart_group=group;
+  }
+}
+
+
+void RDCartDialog::schedcodeActivatedData(const QString &schedcode)
+{
+  filterChangedData("");
+  if(cart_schedcode!=NULL) {
+    *cart_schedcode=schedcode;
+  }
+  if(cart_schedcode!=NULL) {
+    *cart_schedcode=schedcode;
+  }
+}
+
+
+void RDCartDialog::limitChangedData(int state)
+{
+  filterChangedData("");
 }
 
 
@@ -411,7 +512,7 @@ void RDCartDialog::editorData()
     delete q;
     return;
   }
-  QString cmd=cart_edit_cmd;
+  QString cmd=cart_station->editorPath();
   cmd.replace("%f",RDCut::pathName(q->value(0).toString()));
   cmd.replace("%n",QString().sprintf("%06u",item->text(1).toUInt()));
   cmd.replace("%h",QString().sprintf("%d",q->value(1).toInt()));
@@ -436,6 +537,100 @@ void RDCartDialog::editorData()
 }
 
 
+void RDCartDialog::loadFileData()
+{
+#ifndef WIN32
+  QString filename;
+  RDGroup *group=NULL;
+  RDCart *cart=NULL;
+  RDCut *cut=NULL;
+  RDAudioImport *conv;
+  RDAudioImport::ErrorCode err; 
+  RDAudioConvert::ErrorCode conv_err;
+  RDSettings settings;
+  unsigned cartnum=0;
+  QString file_title="";
+  RDWaveFile *wavefile=NULL;
+  RDWaveData wavedata;
+
+  filename=QFileDialog::getOpenFileName(cart_import_path,
+					cart_import_file_filter,this);
+  if(!filename.isEmpty()) {
+
+    //
+    // Get Cart Number
+    //
+    cart_import_path=RDGetPathPart(filename);
+    group=new RDGroup(cart_system->tempCartGroup());
+    if((!group->exists())||((cartnum=group->nextFreeCart())==0)) {
+      delete group;
+      QMessageBox::warning(this,tr("Cart Error"),
+		       tr("Unable to get temporary cart number for import!"));
+      return;
+    }
+    delete group;
+
+    //
+    // Create Cart
+    //
+    cart=new RDCart(cartnum);
+    if(!cart->create(cart_system->tempCartGroup(),RDCart::Audio)) {
+      delete cart;
+      QMessageBox::warning(this,tr("Cart Error"),
+			   tr("Unable to create temporary cart for import!"));
+      return;
+    }
+    cart->setOwner(cart_station->name());
+    cut=new RDCut(cartnum,1,true);
+
+    //
+    // Import Audio
+    //
+    cart_busy_dialog->show(tr("Importing"),tr("Importing..."));
+    conv=new RDAudioImport(cart_station,cart_config,this);
+    conv->setCartNumber(cartnum);
+    conv->setCutNumber(1);
+    conv->setSourceFile(filename);
+    settings.setChannels(2);
+    settings.setNormalizationLevel(-11);
+    conv->setDestinationSettings(&settings);
+    conv->setUseMetadata(true);
+    err=conv->runImport(cart_user_name,cart_user_password,&conv_err);
+    cart_busy_dialog->hide();
+    switch(conv_err) {
+    case RDAudioImport::ErrorOk:
+      break;
+
+    default:
+      QMessageBox::warning(this,tr("Import Error"),
+			   RDAudioImport::errorText(err,conv_err));
+      delete conv;
+      delete cart;
+      delete cut;
+      return;
+    }
+
+    //
+    // Check Metadata
+    //
+    wavefile=new RDWaveFile(filename);
+    if(wavefile->openWave(&wavedata)) {
+      if((!wavedata.metadataFound())||(wavedata.title().isEmpty())) {
+	cart->setTitle(tr("Imported from")+" "+RDGetBasePart(filename));
+      }
+    }
+
+    *cart_cartnum=cartnum;
+    *cart_temp_allowed=true;
+    delete conv;
+    delete cart;
+    delete cut;
+    done(0);
+  }
+#endif  // WIN32
+}
+
+
 void RDCartDialog::okData()
 {
   RDListViewItem *item=(RDListViewItem *)cart_cart_list->currentItem();
@@ -444,6 +639,7 @@ void RDCartDialog::okData()
   }
 
 #ifndef WIN32
+  SaveState();
   if(cart_player!=NULL) {
     cart_player->stop();
   }
@@ -452,6 +648,9 @@ void RDCartDialog::okData()
     *cart_filter=cart_filter_edit->text();
   }
   *cart_cartnum=item->text(1).toInt();
+  if(cart_temp_allowed!=NULL) {
+    *cart_temp_allowed=false;
+  }
   done(0);
 }
 
@@ -459,6 +658,7 @@ void RDCartDialog::okData()
 void RDCartDialog::cancelData()
 {
 #ifndef WIN32
+  SaveState();
   if(cart_player!=NULL) {
     cart_player->stop();
   }
@@ -473,11 +673,16 @@ void RDCartDialog::resizeEvent(QResizeEvent *e)
 
   cart_search_button->setGeometry(size().width()-160,5,70,30);
   cart_clear_button->setGeometry(size().width()-80,5,70,30);
-  cart_group_box->setGeometry(100,35,150,20);
-  cart_group_label->setGeometry(10,35,85,20);
-  cart_cart_label->setGeometry(15,60,100,20);
-  cart_cart_list->setGeometry(10,80,size().width()-20,size().height()-150);
+  cart_group_box->setGeometry(100,40,150,20);
+  cart_group_label->setGeometry(10,40,85,20);
+  cart_schedcode_box->setGeometry(390,40,150,20);
+  cart_schedcode_label->setGeometry(280,40,105,20);
+  cart_limit_box->setGeometry(100,72,15,15);
+  cart_limit_label->setGeometry(120,70,300,20);
+  cart_cart_label->setGeometry(15,90,100,20);
+  cart_cart_list->setGeometry(10,110,size().width()-20,size().height()-180);
   cart_editor_button->setGeometry(235,size().height()-60,80,50);
+  cart_file_button->setGeometry(325,size().height()-60,80,50);
   cart_ok_button->setGeometry(size().width()-180,size().height()-60,80,50);
   cart_cancel_button->setGeometry(size().width()-90,size().height()-60,80,50);
   switch(cart_filter_mode) {
@@ -521,27 +726,37 @@ void RDCartDialog::RefreshCarts()
   if(group==QString(tr("ALL"))) {
     group="";
   }
+  QString schedcode=cart_schedcode_box->currentText();
+  if(group==QString(tr("ALL"))) {
+    schedcode="";
+  }
   if(cart_type==RDCart::All) {
     sql=QString().sprintf("select CART.NUMBER,CART.TITLE,CART.ARTIST,\
                            CART.CLIENT,CART.AGENCY,CART.USER_DEFINED,\
+                           CART.COMPOSER,CART.CONDUCTOR,\
                            CART.START_DATETIME,CART.END_DATETIME,CART.TYPE,\
                            CART.FORCED_LENGTH,CART.GROUP_NAME,GROUPS.COLOR \
                            from CART left join GROUPS \
                            on CART.GROUP_NAME=GROUPS.NAME where %s",
 		 (const char *)GetSearchFilter(cart_filter_edit->text(),
-						group));
+					       group,schedcode));
   }
   else {
     sql=QString().sprintf("select CART.NUMBER,CART.TITLE,CART.ARTIST,\
                            CART.CLIENT,CART.AGENCY,CART.USER_DEFINED,\
+                           CART.COMPOSER,CART.CONDUCTOR,\
                            CART.START_DATETIME,CART.END_DATETIME,CART.TYPE,\
                            CART.FORCED_LENGTH,CART.GROUP_NAME,GROUPS.COLOR \
                            from CART left join GROUPS \
                            on CART.GROUP_NAME=GROUPS.NAME \
                            where (%s)&&(TYPE=%d)",
-		(const char *)GetSearchFilter(cart_filter_edit->text(),group),
+			(const char *)GetSearchFilter(cart_filter_edit->text(),
+						      group,schedcode),
 			  cart_type);
   }
+  if(cart_limit_box->isChecked()) {
+    sql+=QString().sprintf(" limit %d",RD_LIMITED_CART_SEARCH_QUANTITY);
+  }
   q=new RDSqlQuery(sql);
   int step=0;
   int count=0;
@@ -549,8 +764,8 @@ void RDCartDialog::RefreshCarts()
   cart_progress_dialog->setProgress(0);
   while(q->next()) {
     l=new RDListViewItem(cart_cart_list);
-    l->setId(q->value(8).toUInt());
-    switch((RDCart::Type)q->value(8).toUInt()) {
+    l->setId(q->value(10).toUInt());
+    switch((RDCart::Type)q->value(10).toUInt()) {
 	case RDCart::Audio:
 	  l->setPixmap(0,*cart_playout_map);
 	  break;
@@ -563,22 +778,24 @@ void RDCartDialog::RefreshCarts()
 	  break;
     }
     l->setText(1,QString().sprintf("%06d",q->value(0).toUInt())); // Number
-    l->setText(2,RDGetTimeLength(q->value(9).toInt(),false,true)); // Length
+    l->setText(2,RDGetTimeLength(q->value(11).toInt(),false,true)); // Length
     l->setText(3,q->value(1).toString());                       // Title
     l->setText(4,q->value(2).toString());                       // Artist
-    l->setText(5,q->value(10).toString());                      // Group
-    l->setTextColor(5,q->value(11).toString(),QFont::Bold);
-    l->setText(6,q->value(3).toString());                       // Client
-    l->setText(7,q->value(4).toString());                       // Agency
-    l->setText(8,q->value(5).toString());                       // User Defined
-    if(!q->value(6).toDate().isNull()) {
-      l->setText(9,q->value(6).toDate().toString("MM/dd/yyyy"));  // Start Date
-    }
+    l->setText(5,q->value(12).toString());                      // Group
+    l->setText(6,q->value(6).toString());                      // Composer
+    l->setText(7,q->value(7).toString());                      // Conductor
+    l->setTextColor(5,q->value(13).toString(),QFont::Bold);
+    l->setText(8,q->value(3).toString());                       // Client
+    l->setText(9,q->value(4).toString());                       // Agency
+    l->setText(10,q->value(5).toString());                       // User Defined
     if(!q->value(8).toDate().isNull()) {
-      l->setText(10,q->value(7).toDate().toString("MM/dd/yyyy"));  // End Date
+      l->setText(11,q->value(8).toDate().toString("MM/dd/yyyy"));  // Start Date
+    }
+    if(!q->value(10).toDate().isNull()) {
+      l->setText(12,q->value(9).toDate().toString("MM/dd/yyyy"));  // End Date
     }
     else {
-      l->setText(10,"TFN");
+      l->setText(12,"TFN");
     }
     if(*cart_cartnum==q->value(0).toInt()) {
       active_item=l;
@@ -600,6 +817,9 @@ void RDCartDialog::BuildGroupList()
   QString sql;
   RDSqlQuery *q;
   
+  //
+  // Groups
+  //
   cart_group_box->clear();
   cart_group_box->insertItem(tr("ALL"));
   sql="select GROUP_NAME from AUDIO_PERMS";
@@ -631,15 +851,45 @@ void RDCartDialog::BuildGroupList()
       }
     }
   }
+
+  //
+  // Scheduler Codes
+  //
+  cart_schedcode_box->clear();
+  cart_schedcode_box->insertItem(tr("ALL"));
+  sql="select CODE from SCHED_CODES";
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    cart_schedcode_box->insertItem(q->value(0).toString());
+  }
+  delete q;
+
+  //
+  // Preselect Scheduler Code
+  //
+  if(cart_schedcode!=NULL) {
+    for(int i=0;i<cart_schedcode_box->count();i++) {
+      if(*cart_schedcode==cart_schedcode_box->text(i)) {
+	cart_schedcode_box->setCurrentItem(i);
+	return;
+      }
+    }
+  }
 }
 
 
-QString RDCartDialog::GetSearchFilter(QString filter,QString group)
+QString RDCartDialog::GetSearchFilter(const QString &filter,
+				      const QString &group,
+				      const QString &schedcode)
 {
   QString sql;
   RDSqlQuery *q;
-
-  QString search=RDCartSearchText(filter,group).utf8();
+  QString sched="";
+  
+  if(schedcode!=tr("ALL")) {
+    sched=schedcode;
+  }
+  QString search=RDCartSearchText(filter,group,sched,false).utf8();
 
   //
   // Excluded Groups
@@ -659,3 +909,35 @@ QString RDCartDialog::GetSearchFilter(QString filter,QString group)
   return search;
 }
 
+
+void RDCartDialog::LoadState()
+{
+  if(getenv("HOME")==NULL) {
+    return;
+  }
+  RDProfile *p=new RDProfile();
+  p->setSource(QString().sprintf("%s/.rdcartdialog",getenv("HOME")));
+  delete p;
+}
+
+
+void RDCartDialog::SaveState()
+{
+  FILE *f=NULL;
+
+  if(getenv("HOME")==NULL) {
+    return;
+  }
+  if((f=fopen(QString().sprintf("%s/.rdcartdialog",getenv("HOME")),"w"))==
+    NULL) {
+    return;
+  }
+  fprintf(f,"[RDCartDialog]\n");
+  if(cart_limit_box->isChecked()) {
+    fprintf(f,"LimitSearch=Yes\n");
+  }
+  else {
+    fprintf(f,"LimitSearch=No\n");
+  }
+  fclose(f);
+}
