@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcut.cpp,v 1.76.6.6 2013/02/27 21:21:53 cvs Exp $
+//      $Id: rdcut.cpp,v 1.76.6.10.2.1 2014/05/22 14:30:45 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -808,7 +808,7 @@ void RDCut::logPlayout() const
 
 
 bool RDCut::copyTo(RDStation *station,RDUser *user,
-		   const QString &cutname) const
+		   const QString &cutname,RDConfig *config) const
 {
 #ifdef WIN32
   return false;
@@ -880,18 +880,13 @@ bool RDCut::copyTo(RDStation *station,RDUser *user,
   //
   // Copy the Audio
   //
-  RDCopyAudio *conv=new RDCopyAudio(station);
+  RDCopyAudio *conv=new RDCopyAudio(station,config);
   conv->setSourceCartNumber(cart_number);
   conv->setSourceCutNumber(cut_number);
   conv->setDestinationCartNumber(RDCut::cartNumber(cutname));
   conv->setDestinationCutNumber(RDCut::cutNumber(cutname));
   ret=conv->runCopy(user->name(),user->password())==RDCopyAudio::ErrorOk;
   delete conv;
-  /*
-  QString srcname=RDCut::pathName(cut_name); 
-  QString destname=RDCut::pathName(cutname); 
-  FileCopy(srcname,destname);
-  */
 
   return ret;
 #endif
@@ -991,7 +986,7 @@ void RDCut::setMetadata(RDWaveData *data) const
       }
     }
     if(data->introEndPos()>=0) {
-      if(data->introEndPos()>data->endPos()) {
+      if((data->introEndPos()>data->endPos())&&(data->endPos()!=-1)) {
 	sql+=QString().sprintf("TALK_END_POINT=%d,",data->endPos());
       }
       else {
@@ -1014,7 +1009,12 @@ void RDCut::setMetadata(RDWaveData *data) const
     }
     if(data->segueEndPos()>=0) {
       if(data->segueEndPos()>data->endPos()) {
-	sql+=QString().sprintf("SEGUE_END_POINT=%d,",data->endPos());
+	if(data->endPos()<0) {
+	  sql+=QString().sprintf("SEGUE_END_POINT=%d,",data->segueStartPos()+1);
+	}
+	else {
+	  sql+=QString().sprintf("SEGUE_END_POINT=%d,",data->endPos());
+	}
       }
       else {
 	sql+=QString().sprintf("SEGUE_END_POINT=%d,",data->segueEndPos());
@@ -1411,6 +1411,10 @@ void RDCut::disconnect(QObject *receiver,const char *member) const
 
 QString RDCut::cutName(unsigned cartnum,unsigned cutnum)
 {
+  if((cartnum<1)||(cartnum>RD_MAX_CART_NUMBER)||
+     (cutnum<1)||(cutnum>RD_MAX_CUT_NUMBER)) {
+    return QString();
+  }
   return QString().sprintf("%06u_%03u",cartnum,cutnum);
 }
 
