@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_dropbox.h,v 1.2.2.1 2008-11-29 15:48:10 fredg Exp $
+//      $Id: edit_dropbox.h,v 1.5.8.1.2.1 2014/06/03 18:23:36 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -35,8 +35,10 @@
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
+#include <qstringlist.h>
 
 #include <rddropbox.h>
+#include <rdschedcodes_dialog.h>
 
 
 class EditDropbox : public QDialog
@@ -52,8 +54,10 @@ class EditDropbox : public QDialog
   void selectCartData();
   void toCartChangedData(const QString &str);
   void selectLogPathData();
+  void schedcodesData();
   void normalizationToggledData(bool state);
   void autotrimToggledData(bool state);
+  void createDatesToggledData(bool state);
   void okData();
   void cancelData();
   
@@ -62,9 +66,11 @@ class EditDropbox : public QDialog
   QComboBox *box_group_name_box;
   QLineEdit *box_path_edit;
   QLineEdit *box_to_cart_edit;
+  QPushButton *box_schedcodes_button;
   QCheckBox *box_delete_cuts_box;
   QLabel *box_delete_cuts_label;
   QLineEdit *box_metadata_pattern_edit;
+  QLineEdit *box_user_defined_edit;
   QLineEdit *box_log_path_edit;
   QCheckBox *box_delete_source_box;
   QCheckBox *box_normalization_box;
@@ -81,6 +87,15 @@ class EditDropbox : public QDialog
   QPushButton *box_select_cart_button;
   QSpinBox *box_startoffset_spin;
   QSpinBox *box_endoffset_spin;
+  QCheckBox *box_create_dates_box;
+  QSpinBox *box_create_startdate_offset_spin;
+  QLabel *box_create_startdate_label;
+  QLabel *box_create_startdate_unit;
+  QSpinBox *box_create_enddate_offset_spin;
+  QLabel *box_create_enddate_label;
+  QLabel *box_create_enddate_unit;
+  RDSchedCodesDialog *box_schedcodes_dialog;
+  QStringList box_schedcodes;
 };
 
 
