@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: log_play.h,v 1.90 2010/07/29 19:32:36 cvs Exp $
+//      $Id: log_play.h,v 1.90.8.3.2.1 2014/05/22 19:37:45 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -72,7 +72,7 @@ class LogPlay : public QObject,public RDLogEvent
   int card(int channum) const;
   int port(int channum) const;
   RDAirPlayConf::OpMode mode() const;
-  void setMode(RDAirPlayConf::OpMode mode);
+  void setOpMode(RDAirPlayConf::OpMode mode);
   void setLogName(QString name);
   void setChannels(int cards[2],int ports[2],
 		   const QString start_rml[2],const QString stop_rml[2]);
@@ -84,12 +84,15 @@ class LogPlay : public QObject,public RDLogEvent
   void auditionStop();
   bool play(int line,RDLogLine::StartSource src,
 	    int mport=-1,bool skip_meta=false);
+  bool channelPlay(int mport);
   bool stop(bool all=true,int port=0,int fade=0);
   bool stop(int line,int fade=0);
+  bool channelStop(int mport);
   bool pause(int line);
   void duckVolume(int level,int fade,int mport=-1);
   void makeNext(int line,bool refresh_status=true);
   void load();
+  void append(const QString &log_name);
   bool refresh();
   void save(int line=-1);
   void clear();
@@ -156,6 +159,8 @@ class LogPlay : public QObject,public RDLogEvent
   void runStatusChanged(bool running);
   void refreshabilityChanged(bool state);
   void refreshStatusChanged(bool active);
+  void channelStarted(int id,int mport,int card,int port);
+  void channelStopped(int id,int mport,int card,int port);
 
  private:
   bool StartEvent(int line,RDLogLine::TransType trans_type,int trans_length,
@@ -171,7 +176,6 @@ class LogPlay : public QObject,public RDLogEvent
   QTime GetNextStop(int line);
   void UpdatePostPoint();
   void UpdatePostPoint(int line);
-//  int NextPostPoint(int line,QTime *start,int *offset);
   void AdvanceActiveEvent();
   void SetTransTimer(QTime current_time=QTime(),bool stop=true);
   QString GetPortName(int card,int port);
