@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: audio_cart.h,v 1.17 2007/12/26 21:45:43 grauf Exp $
+//      $Id: audio_cart.h,v 1.19.8.2.2.1 2014/03/19 22:12:58 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,6 +23,8 @@
 #ifndef AUDIO_CART_H
 #define AUDIO_CART_H
 
+#include <vector>
+
 #include <qwidget.h>
 #include <qlabel.h>
 #include <qlistbox.h>
@@ -51,7 +53,7 @@ class AudioCart : public QWidget
   Q_OBJECT
  public:
   AudioCart(AudioControls *controls,RDCart *cart,QString *path,bool select_cut,
-	    QWidget *parent=0,const char *name=0);
+	    bool profile_rip,QWidget *parent=0,const char *name=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
@@ -78,13 +80,12 @@ class AudioCart : public QWidget
   void audioChanged();
 
  private:
+  RDListViewItem *SelectedCuts(std::vector<QString> *cutnames);
   void RefreshList();
   void RefreshLine(RDListViewItem *item);
   unsigned NextCut();
-  void UpdateCutCount();
   RDCart *rdcart_cart;
   RDListView *rdcart_cut_list;
-  QLabel *rdcart_cut_list_label;
   unsigned rdcart_average_length;
   QString *rdcart_import_path;
   bool rdcart_select_cut;
@@ -93,6 +94,7 @@ class AudioCart : public QWidget
   QProgressDialog *rdcart_progress_dialog;
   bool rdcart_modification_allowed;
   bool rdcart_import_metadata;
+  bool rdcart_profile_rip;
 };
 
 
