@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: bt16x1.h,v 1.4 2007-09-14 14:06:59 fredg Exp $
+//      $Id: bt16x1.h,v 1.9 2010/08/03 23:39:25 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,27 +23,28 @@
 #ifndef BT16X1_H
 #define BT16X1_H
 
-#include <qobject.h>
-
 #include <rd.h>
 #include <rdmatrix.h>
 #include <rdmacro.h>
 #include <rdtty.h>
 
+#include <switcher.h>
+
 #define BT16X1_MIN_GAIN -99
 #define BT16X1_MAX_GAIN 28
 
-class Bt16x1 : public QObject
+class Bt16x1 : public Switcher
 {
  Q_OBJECT
  public:
  Bt16x1(RDMatrix *matrix,QObject *parent=0,const char *name=0);
   ~Bt16x1();
+  RDMatrix::Type type();
+  unsigned gpiQuantity();
+  unsigned gpoQuantity();
+  bool primaryTtyActive();
+  bool secondaryTtyActive();
   void processCommand(RDMacro *cmd);
-  void processStatus(char *buf,int size);
-
- signals:
-  void rmlEcho(RDMacro *cmd);
 
  private:
   RDTTYDevice *bt_device;
