@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: local_gpio.cpp,v 1.11 2008/10/01 13:10:15 fredg Exp $
+//      $Id: local_gpio.cpp,v 1.16.8.1 2013/03/03 23:30:16 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,9 +25,8 @@
 #include <globals.h>
 #include <local_gpio.h>
 
-
 LocalGpio::LocalGpio(RDMatrix *matrix,QObject *parent,const char *name)
-  : QObject(parent,name)
+  : Switcher(matrix,parent,name)
 {
   //
   // Get Matrix Parameters
@@ -48,7 +47,7 @@ LocalGpio::LocalGpio(RDMatrix *matrix,QObject *parent,const char *name)
   //
   gpio_gpio=new RDGpio(this,"gpio_gpio");
   gpio_gpio->setDevice(matrix->gpioDevice());
-  if(gpio_open=gpio_gpio->open()) {
+  if((gpio_open=gpio_gpio->open())) {
     if(gpio_gpis==0) {
       gpio_gpio->setMode(RDGpio::Output);
     }
@@ -77,6 +76,36 @@ LocalGpio::~LocalGpio()
 }
 
 
+RDMatrix::Type LocalGpio::type()
+{
+  return RDMatrix::LocalGpio;
+}
+
+
+unsigned LocalGpio::gpiQuantity()
+{
+  return gpio_gpis;
+}
+
+
+unsigned LocalGpio::gpoQuantity()
+{
+  return gpio_gpos;
+}
+
+
+bool LocalGpio::primaryTtyActive()
+{
+  return false;
+}
+
+
+bool LocalGpio::secondaryTtyActive()
+{
+  return false;
+}
+
+
 void LocalGpio::processCommand(RDMacro *cmd)
 {
   switch(cmd->command()) {
